+++
title = "Reference"
weight:10
+++

# Jobs


## FileGeneratingJob


## MultiFileGeneratingJob


## TempFileGeneratingJob / MultiTempFileGeneratingJob

# Managing pipegraphs 


# handy utilities


# external utilities


